<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: notebooks/index.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

# Incendio

> A mini-library of PyTorch utilities, wrappers, and miscellaneous tools for deep learning.


## Install

`pip install incendio`

## Documentation

https://hdmamin.github.io/incendio/
